@@ -2,7 +2,7 @@ from urge.base import ProcManager, action
 from path import Path
 
 
-def web_screenshot(url: str, target: str = "./", use_mobile=True,**kwargs) -> str:
+def web_screenshot(url: str, target: str = "./", use_mobile=True, **kwargs) -> str:
 
     from playwright.sync_api import sync_playwright
     from datetime import datetime
@@ -15,8 +15,8 @@ def web_screenshot(url: str, target: str = "./", use_mobile=True,**kwargs) -> st
         print("🤖 : Hey, I found the chromium binary...")
         print(browser_type)
         print(
-            '🤖 : Launching browser... Please wait for a while then you will see the'
-            ' result.'
+            "🤖 : Launching browser... Please wait for a while then you will see the"
+            " result."
         )
         browser = browser_type.launch(headless=True)
         if not use_mobile:
@@ -29,11 +29,14 @@ def web_screenshot(url: str, target: str = "./", use_mobile=True,**kwargs) -> st
 
         page.goto(url, wait_until="networkidle")
         # page.screenshot(path=f'./example-{browser_type.name}haha.png')
-        target = Path(target) 
-        file_name = target/f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.jpeg'
-        page.screenshot(path=file_name,type="jpeg",quality=20)
+        target = Path(target)
+        file_name = (
+            target / f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.png'
+        )
+        page.screenshot(path=file_name, type="jpeg", quality=20)
+        # page.screenshot(path=file_name, type="png")
         print(f"🤖 : DONE")
-        print(f'The file is at {file_name}')
+        print(f"The file is at {file_name}")
         browser.close()
     return file_name
 
